from PyObjCTools.TestSupport import TestCase, min_os_level
import AVKit
import objc


class TestAVCaptureView(TestCase):
    @min_os_level("10.10")
    def testClasses(self):
        self.assertIsInstance(AVKit.AVCaptureView, objc.objc_class)

    @min_os_level("10.10")
    def testProtocols(self):
        self.assertIsInstance(
            objc.protocolNamed("AVCaptureViewDelegate"), objc.formal_protocol
        )

    @min_os_level("10.10")
    def testMethods(self):
        self.assertArgIsBOOL(
            AVKit.AVCaptureView.setSession_showVideoPreview_showAudioPreview_, 1
        )
        self.assertArgIsBOOL(
            AVKit.AVCaptureView.setSession_showVideoPreview_showAudioPreview_, 2
        )

    @min_os_level("10.10")
    def test_constants(self):
        self.assertEqual(AVKit.AVCaptureViewControlsStyleInline, 0)
        self.assertEqual(AVKit.AVCaptureViewControlsStyleFloating, 1)
        self.assertEqual(AVKit.AVCaptureViewControlsStyleInlineDeviceSelection, 2)
        self.assertEqual(
            AVKit.AVCaptureViewControlsStyleDefault,
            AVKit.AVCaptureViewControlsStyleInline,
        )



# This file is generated by objective.metadata
#
# Last update: Thu Jul 23 13:58:15 2020
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


misc = {}
constants = """$$"""
enums = """$AVCaptureViewControlsStyleDefault@0$AVCaptureViewControlsStyleFloating@1$AVCaptureViewControlsStyleInline@0$AVCaptureViewControlsStyleInlineDeviceSelection@2$AVPlayerViewControlsStyleDefault@1$AVPlayerViewControlsStyleFloating@2$AVPlayerViewControlsStyleInline@1$AVPlayerViewControlsStyleMinimal@3$AVPlayerViewControlsStyleNone@0$AVPlayerViewTrimCancelButton@1$AVPlayerViewTrimOKButton@0$AVRoutePickerViewButtonStateActive@2$AVRoutePickerViewButtonStateActiveHighlighted@3$AVRoutePickerViewButtonStateNormal@0$AVRoutePickerViewButtonStateNormalHighlighted@1$"""
misc.update({})
aliases = {
    "AVPlayerViewControlsStyleDefault": "AVPlayerViewControlsStyleInline",
    "AVCaptureViewControlsStyleDefault": "AVCaptureViewControlsStyleInline",
}
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"AVCaptureView",
        b"setSession:showVideoPreview:showAudioPreview:",
        {"arguments": {3: {"type": b"Z"}, 4: {"type": b"Z"}}},
    )
    r(
        b"AVPictureInPictureController",
        b"canStopPictureInPicture",
        {"retval": {"type": "Z"}},
    )
    r(
        b"AVPictureInPictureController",
        b"isPictureInPictureActive",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"AVPictureInPictureController",
        b"isPictureInPicturePossible",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"AVPictureInPictureController",
        b"isPictureInPictureSupported",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"AVPictureInPictureController",
        b"isPictureInPictureSuspended",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"AVPictureInPictureController",
        b"requiresLinearPlayback",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"AVPictureInPictureController",
        b"setRequiresLinearPlayback:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"AVPlayerView", b"allowsPictureInPicturePlayback", {"retval": {"type": b"Z"}})
    r(
        b"AVPlayerView",
        b"beginTrimmingWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"q"}},
                    }
                }
            }
        },
    )
    r(b"AVPlayerView", b"canBeginTrimming", {"retval": {"type": b"Z"}})
    r(b"AVPlayerView", b"isReadyForDisplay", {"retval": {"type": b"Z"}})
    r(
        b"AVPlayerView",
        b"setAllowsPictureInPicturePlayback:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"AVPlayerView",
        b"setShowsFrameSteppingButtons:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"AVPlayerView",
        b"setShowsFullScreenToggleButton:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"AVPlayerView",
        b"setShowsSharingServiceButton:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"AVPlayerView", b"setShowsTimecodes:", {"arguments": {2: {"type": b"Z"}}})
    r(
        b"AVPlayerView",
        b"setUpdatesNowPlayingInfoCenter:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(b"AVPlayerView", b"showsFrameSteppingButtons", {"retval": {"type": b"Z"}})
    r(b"AVPlayerView", b"showsFullScreenToggleButton", {"retval": {"type": b"Z"}})
    r(b"AVPlayerView", b"showsSharingServiceButton", {"retval": {"type": b"Z"}})
    r(b"AVPlayerView", b"showsTimecodes", {"retval": {"type": b"Z"}})
    r(b"AVPlayerView", b"updatesNowPlayingInfoCenter", {"retval": {"type": "Z"}})
    r(b"AVRoutePickerView", b"isRoutePickerButtonBordered", {"retval": {"type": "Z"}})
    r(
        b"AVRoutePickerView",
        b"setRoutePickerButtonBordered:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(
        b"NSObject",
        b"captureView:startRecordingToFileOutput:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"pictureInPictureController:failedToStartPictureInPictureWithError:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"pictureInPictureController:restoreUserInterfaceForPictureInPictureStopWithCompletionHandler:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"Z"}},
                    },
                    "type": b"@?",
                },
            },
        },
    )
    r(
        b"NSObject",
        b"pictureInPictureControllerDidStartPictureInPicture:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"pictureInPictureControllerDidStopPictureInPicture:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"pictureInPictureControllerWillStartPictureInPicture:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"pictureInPictureControllerWillStopPictureInPicture:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"playerView:failedToStartPictureInPictureWithError:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"playerView:restoreUserInterfaceForPictureInPictureStopWithCompletionHandler:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"Z"}},
                    },
                    "type": b"@?",
                },
            },
        },
    )
    r(
        b"NSObject",
        b"playerViewDidStartPictureInPicture:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"playerViewDidStopPictureInPicture:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"playerViewShouldAutomaticallyDismissAtPictureInPictureStart:",
        {"required": False, "retval": {"type": b"Z"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"playerViewWillStartPictureInPicture:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"playerViewWillStopPictureInPicture:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"routePickerViewDidEndPresentingRoutes:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"routePickerViewWillBeginPresentingRoutes:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



from PyObjCTools.TestSupport import TestCase, min_os_level, min_sdk_level
import AVKit
import objc


class TestAVRoutePickerView(TestCase):
    def test_constants(self):
        self.assertEqual(AVKit.AVRoutePickerViewButtonStateNormal, 0)
        self.assertEqual(AVKit.AVRoutePickerViewButtonStateNormalHighlighted, 1)
        self.assertEqual(AVKit.AVRoutePickerViewButtonStateActive, 2)
        self.assertEqual(AVKit.AVRoutePickerViewButtonStateActiveHighlighted, 3)

    @min_os_level("10.15")
    def test_methods(self):
        self.assertResultIsBOOL(AVKit.AVRoutePickerView.isRoutePickerButtonBordered)
        self.assertArgIsBOOL(AVKit.AVRoutePickerView.setRoutePickerButtonBordered_, 0)

    @min_sdk_level("10.15")
    def test_protocols(self):
        objc.protocolNamed("AVRoutePickerViewDelegate")



"""
Python mapping for the AddressBook framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import Cocoa
import objc
import Quartz
from AVKit import _AVKit, _metadata

sys.modules["AVKit"] = mod = objc.ObjCLazyModule(
    "AVKit",
    "com.apple.AVKit",
    objc.pathForFramework("/System/Library/Frameworks/AVKit.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
    },
    (_AVKit, Cocoa, Quartz),
)


del sys.modules["AVKit._metadata"]
del sys.modules["AVKit._AVKit"]



from PyObjCTools.TestSupport import TestCase, min_os_level, min_sdk_level
import AVKit
import objc


class TestAVPlayerViewHelper(AVKit.NSObject):
    def playerView_restoreUserInterfaceForPictureInPictureStopWithCompletionHandler_(  # noqa: B950
        self, a, b
    ):
        pass

    def playerViewShouldAutomaticallyDismissAtPictureInPictureStart_(self, a):
        return 1


class TestAVPlayerView(TestCase):
    @min_os_level("10.9")
    def testClasses(self):
        self.assertIsInstance(AVKit.AVPlayerView, objc.objc_class)

    @min_os_level("10.9")
    def testMethods10_9(self):
        self.assertArgIsBOOL(AVKit.AVPlayerView.setShowsFrameSteppingButtons_, 0)
        self.assertResultIsBOOL(AVKit.AVPlayerView.showsFrameSteppingButtons)
        self.assertArgIsBOOL(AVKit.AVPlayerView.setShowsSharingServiceButton_, 0)
        self.assertResultIsBOOL(AVKit.AVPlayerView.showsSharingServiceButton)
        self.assertArgIsBOOL(AVKit.AVPlayerView.setShowsFullScreenToggleButton_, 0)
        self.assertResultIsBOOL(AVKit.AVPlayerView.showsFullScreenToggleButton)
        self.assertResultIsBOOL(AVKit.AVPlayerView.canBeginTrimming)

        self.assertArgIsBlock(
            AVKit.AVPlayerView.beginTrimmingWithCompletionHandler_,
            0,
            b"v" + objc._C_NSInteger,
        )

    @min_os_level("10.10")
    def testMethods10_10(self):
        self.assertResultIsBOOL(AVKit.AVPlayerView.isReadyForDisplay)

    @min_os_level("10.13")
    def testMethods10_13(self):
        self.assertArgIsBOOL(AVKit.AVPlayerView.setUpdatesNowPlayingInfoCenter_, 0)
        self.assertResultIsBOOL(AVKit.AVPlayerView.updatesNowPlayingInfoCenter)

    @min_os_level("10.15")
    def testMethods10_15(self):
        self.assertArgIsBOOL(AVKit.AVPlayerView.setShowsTimecodes_, 0)
        self.assertResultIsBOOL(AVKit.AVPlayerView.showsTimecodes)

        self.assertResultIsBOOL(AVKit.AVPlayerView.allowsPictureInPicturePlayback)
        self.assertArgIsBOOL(AVKit.AVPlayerView.setAllowsPictureInPicturePlayback_, 0)

        self.assertArgIsBlock(
            TestAVPlayerViewHelper.playerView_restoreUserInterfaceForPictureInPictureStopWithCompletionHandler_,  # noqa: B950
            1,
            b"vZ",
        )
        self.assertResultIsBOOL(
            TestAVPlayerViewHelper.playerViewShouldAutomaticallyDismissAtPictureInPictureStart_  # noqa: B950
        )

    @min_os_level("10.9")
    def test_constants(self):
        self.assertEqual(AVKit.AVPlayerViewControlsStyleNone, 0)
        self.assertEqual(AVKit.AVPlayerViewControlsStyleInline, 1)
        self.assertEqual(AVKit.AVPlayerViewControlsStyleFloating, 2)
        self.assertEqual(AVKit.AVPlayerViewControlsStyleMinimal, 3)
        self.assertEqual(
            AVKit.AVPlayerViewControlsStyleDefault,
            AVKit.AVPlayerViewControlsStyleInline,
            4,
        )

        self.assertEqual(AVKit.AVPlayerViewTrimOKButton, 0)
        self.assertEqual(AVKit.AVPlayerViewTrimCancelButton, 1)

    @min_sdk_level("10.15")
    def test_protocols(self):
        objc.protocolNamed("AVPlayerViewPictureInPictureDelegate")



from PyObjCTools.TestSupport import TestCase, min_os_level, min_sdk_level
import AVKit
import objc


class TestAVPictureInPictureControllerHelper(AVKit.NSObject):
    def pictureInPictureController_restoreUserInterfaceForPictureInPictureStopWithCompletionHandler_(  # noqa: B950
        self, a, b
    ):
        pass


class TestAVPictureInPictureController(TestCase):
    @min_sdk_level("10.15")
    def testProtocols(self):
        objc.protocolNamed("AVPictureInPictureControllerDelegate")

    @min_os_level("10.15")
    def test_methods(self):
        self.assertResultIsBOOL(
            AVKit.AVPictureInPictureController.isPictureInPictureSupported
        )
        self.assertResultIsBOOL(
            AVKit.AVPictureInPictureController.isPictureInPicturePossible
        )
        self.assertResultIsBOOL(
            AVKit.AVPictureInPictureController.isPictureInPictureActive
        )
        self.assertResultIsBOOL(
            AVKit.AVPictureInPictureController.isPictureInPictureSuspended
        )

        self.assertArgIsBlock(
            TestAVPictureInPictureControllerHelper.pictureInPictureController_restoreUserInterfaceForPictureInPictureStopWithCompletionHandler_,  # noqa: B950
            1,
            b"vZ",
        )

    @min_os_level("10.16")
    def test_methods10_16(self):
        self.assertResultIsBOOL(
            AVKit.AVPictureInPictureController.requiresLinearPlayback
        )
        self.assertArgIsBOOL(
            AVKit.AVPictureInPictureController.setRequiresLinearPlayback_, 0
        )

        self.assertResultIsBOOL(
            AVKit.AVPictureInPictureController.canStopPictureInPicture
        )
